#[as_algorithm_args]Expand description
Register new fields on a struct that contains algorithm options. This macro adds:
- the Serialize, Deserialize, Clone traits to the structure to make it serialisable and de-serialisable.
- add the following fields: stopping_condition (
StoppingCondition), parallel (bool) and export_history (Option<ExportHistory>).